'use strict'

import arrayPush from './arrayPush.js'
import isArray   from '../isArray.js'

/**
 * The base implementation of `getAllKeys` and `getAllKeysIn` which uses `keysFunc` and `symbolsFunc` to get the enumerable property names and symbols of `object`.
 * @private
 * @param {Object} object The object to query.
 * @param {Function} keysFunc The function to get the keys of `object`.
 * @param {Function} symbolsFunc The function to get the symbols of `object`.
 * @returns {Array} Returns the array of property names and symbols.
 */
const baseGetAllKeys = ( object, keysFunc, symbolsFunc ) =>
{
    const result = keysFunc( object );
    return isArray(object) ? result : arrayPush(result, symbolsFunc(object)) ;
}

export default baseGetAllKeys;