'use strict'

import baseClamp from '../_/baseClamp.js'
import toInteger from '../numbers/toInteger.js'

/** Used as references for the maximum length and index of an array. */
const MAX_ARRAY_LENGTH = 4294967295;

/**
 * Converts `value` to an integer suitable for use as the length of an array-like object.
 *
 * **Note:** This method is based on
 * [`ToLength`](http://ecma-international.org/ecma-262/7.0/#sec-tolength).
 *
 * @name toLength
 * @memberOf core.arrays
 * @since 1.0.36
 * @static
 * @param {*} value The value to convert.
 * @returns {number} Returns the converted integer.
 * @example
 *
 * toLength(3.2); // 3
 * toLength(Number.MIN_VALUE); // 0
 * toLength(Infinity); // 4294967295
 * toLength('3.2'); 3
 */
const toLength = value => value ? baseClamp(toInteger(value), 0, MAX_ARRAY_LENGTH) : 0 ;

export default toLength;