'use strict'

import baseAt      from '../_/baseAt.js'
import baseFlatten from '../_/baseFlatten.js'

/**
 * Creates an array of values corresponding to `paths` of `object`.
 * @since 1.0.37
 * @name get
 * @memberof core.objects
 * @function
 * @instance
 * @param {Object} object The object to iterate over.
 * @param {...(string|string[])} [paths] The property paths to pick.
 * @returns {Array} Returns the picked values.
 * @example
 * const object = { 'a': [{ 'b': { 'c': 3 } }, 4] } ;
 * console( at(object, ['a[0].b.c', 'a[1]']) ) ; // [3, 4]
 */
const at = (object, ...paths ) => baseAt( object , baseFlatten( paths, 1 ) ) ;

export default at ;